/*
 * pages.h
 *
 * Copyright (c) Chris Putnam 2016-2021
 *
 * Program and source code released under the GPL version 2
 */
#ifndef PAGES_H
#define PAGES_H

#include "bibl.h"

int add_pages( fields *bibout, str *value, int level );

#endif

